//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/locales/en-US/firefox-l10n.js"

//@line 38 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
